==> binnie-mods-1.11.2-2.1.0.36-sources.jar: binnie/core/machines/inventory/SlotValidator.java <==
package binnie.core.machines.inventory;

import javax.annotation.Nullable;

import net.minecraft.client.renderer.texture.TextureAtlasSprite;
import net.minecraft.item.ItemStack;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.genetics.AlleleManager;

public abstract class SlotValidator extends Validator<ItemStack> {
	public static ValidatorSprite spriteBee;
	public static ValidatorSprite spriteFrame;
	public static ValidatorSprite spriteCircuit;
	public static ValidatorSprite spriteBlock;

	@Nullable
	private ValidatorSprite sprite;

	public SlotValidator(@Nullable final ValidatorSprite icon) {
		this.sprite = icon;
	}

	@Nullable
	@SideOnly(Side.CLIENT)
	public TextureAtlasSprite getIcon(final boolean input) {
		return (this.sprite == null) ? null : this.sprite.getSprite(input).getSprite();
	}

	public static class Item extends SlotValidator {
		private ItemStack target;

		public Item(final ItemStack target, final ValidatorSprite icon) {
			super(icon);
			this.target = target;
		}

		@Override
		public boolean isValid(final ItemStack itemStack) {
			return itemStack.func_77969_a(this.target);
		}

		@Override
		public String getTooltip() {
			return this.target.func_82833_r();
		}
	}

	public static class Individual extends SlotValidator {
		public Individual() {
			super(null);
		}

		@Override
		public boolean isValid(final ItemStack itemStack) {
			return AlleleManager.alleleRegistry.getIndividual(itemStack) != null;
		}

		@Override
		public String getTooltip() {
			return "Breedable Individual";
		}
	}
}

==> binnie-mods-1.12-2.3.0.8-sources.jar: binnie/core/machines/inventory/SlotValidator.java <==
package binnie.core.machines.inventory;

import javax.annotation.Nullable;

import net.minecraft.client.renderer.texture.TextureAtlasSprite;
import net.minecraft.item.ItemStack;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.genetics.AlleleManager;

public abstract class SlotValidator extends Validator<ItemStack> {
	public static ValidatorSprite spriteBee;
	public static ValidatorSprite spriteFrame;
	public static ValidatorSprite spriteCircuit;
	public static ValidatorSprite spriteBlock;

	@Nullable
	private ValidatorSprite sprite;

	public SlotValidator(@Nullable final ValidatorSprite icon) {
		this.sprite = icon;
	}

	@Nullable
	@SideOnly(Side.CLIENT)
	public TextureAtlasSprite getIcon(final boolean input) {
		return (this.sprite == null) ? null : this.sprite.getSprite(input).getSprite();
	}

	public static class Item extends SlotValidator {
		private ItemStack target;

		public Item(final ItemStack target, final ValidatorSprite icon) {
			super(icon);
			this.target = target;
		}

		@Override
		public boolean isValid(final ItemStack itemStack) {
			return itemStack.isItemEqual(this.target);
		}

		@Override
		public String getTooltip() {
			return this.target.getDisplayName();
		}
	}

	public static class Individual extends SlotValidator {
		public Individual() {
			super(null);
		}

		@Override
		public boolean isValid(final ItemStack itemStack) {
			return AlleleManager.alleleRegistry.getIndividual(itemStack) != null;
		}

		@Override
		public String getTooltip() {
			return "Breedable Individual";
		}
	}
}
